% Constructor for IIsym objects
% II's are iterated integrals, specifically, IIsym contains the coefficients
% associated with particular iterated integrals.
% an IIsym is defined as II=a_0+Sum(a_i1i2i3..ikX^(i1i2..ik))
% where the sum is done over all combinations (i1,..,in), and i is one the
% drivers (usually, 1 or 2)
% eg: II=1+3X^1+5X^22-10X^211
% This class defines such objects and operations on them.
% +,- and multiplication by a scalar are straightforward
% but multiplication of two II is trickier and involves the shuffle
% product.
% IIsym objects follow the same rules but use symbolic expressions.
%
% Constructor:
% ii=IIsym; creates an empty (zero) II.
% ii=IIsym(c,v); creates a new II with paired values combination c and value v
% ii=IIsym(c,v,MaxDepth); set the MaxDepth i.e. the maximum cardinality of
% the iterated integrals. Default is 5.
% C.Ladroue

function ii=IIsym(varargin)

ii.Pointer={};
ii.Coef=sym([]);
ii.MaxDepth=5;

n=nargin;
if mod(n,2), % odd
    ii.MaxDepth=varargin{n};
    n=n-1;
end;


if nargin>0,
    if isa(varargin{1},'cell'),
        ii.Pointer=varargin{1};
        ii.Coef=varargin{2};
    else
    for k=1:2:n
        ii.Pointer={ii.Pointer{:} varargin{k}};
        ii.Coef=[ii.Coef varargin{k+1}];
    end;
end;
end;

ii=class(ii,'IIsym');
ii=squeeze(ii);
