% Constructor for IIxp object
% IIxp are iterated integral expansions, specifically, IIxp contains the coefficients
% associated with the linear combination of iterated integrals.
% An IIxp is defined as IIxp=a_0+Sum(a_{i_1i_2i_3..i_k} X^(i_1i_2..i_k))
% where the sum is done over all combinations (i_1,..,i_n), and i is one the
% drivers (usually, 1 or 2)
% eg: II=1+3X^(1)+5X^(22)-10X^(211)
% This class defines such objects and the operations on them.
% +,- and multiplication by a scalar are straightforward
% but multiplication of two IIxp's is trickier and involves the shuffle
% product.
%
% Constructor:
% ii=IIxp; creates an empty (zero) IIxp.
% ii=IIxp(c,v); creates a new IIxp with paired values combination c and value v
% ii=IIxp(c,v,MaxDepth); set the MaxDepth i.e. the maximum length of the word. 
%
% You can also use a cell array to populate the IIxp, as in 
% >> IIxp({[1] [1 2]},[5 3])
%
% Default Max word length is 5.
% C.Ladroue

function ii=IIxp(varargin)
ii.Pointer={};
ii.Coef=[];
ii.MaxDepth=5;

n=nargin;
if mod(n,2), % odd
    ii.MaxDepth=varargin{n};
    n=n-1;
end;

if nargin>0,
if isa(varargin{1},'cell'),
    ii.Pointer=varargin{1};
    ii.Coef=varargin{2};
else
    
    for k=1:2:n
        ii.Pointer={ii.Pointer{:} varargin{k}};
        ii.Coef=[ii.Coef varargin{k+1}];
    end;
end;
end;

ii=class(ii,'IIxp');
ii=squeeze(ii);
