#include "mex.h"
#include <math.h>

double factor(double *X, double *w, int i, int j, int k, int m)
{
    int r, p;
    double ans = 1, step = 0;
    
    for(r=1; r<=i-k; r++) {
        p = (int)*(w+i-r)-1;
        step = *(X+m*j+p)-*(X+m*(j-1)+p);
        ans = ans*step/r;
    }
    
    return ans;
}


void Iter_integral(double *X, double *w, int d, int m, int n,
                    double *Y, double *I)
{
   int i, j, k;

   /* Initialize I */
   for(i=0; i<n; i++)
     {
	  *(I+(d+1)*i) = 1;
	  for(j=1; j<=d; j++) {
	     *(I+(d+1)*i+j) = 0;
     }
   }

   /* Compute Iterated Integrals up to w1...wd (as double)*/
   for(i=1; i<=d; i++)  {
     for(j=1; j<n; j++)  {
       for(k=0; k<=i; k++) 
         {
          *(I+(d+1)*j+i) = *(I+(d+1)*j+i) + 
                 *(I+(d+1)*(j-1)+k)*factor(X,w,i,j,k,m);    
         }
       }
    }
    
    /* the answer... */
    for(i=0; i<n; i++) {
      *(Y+i) = *(I+(d+1)*i+d);
    }
}

/* The gateway function. */
void mexFunction(
   int nlhs, mxArray *plhs[],
   int nrhs, const mxArray *prhs[])
{
   int d, m, n;
   double *X, *w, *Y, *I;

   X = mxGetPr(prhs[0]);
   m = mxGetM(prhs[0]);
   n = mxGetN(prhs[0]);
   w = mxGetPr(prhs[1]);
   d = mxGetN(prhs[1]);


   plhs[0] = mxCreateDoubleMatrix(1,n,mxREAL);
   plhs[1] = mxCreateDoubleMatrix(d+1,n,mxREAL);
   
   Y = mxGetPr(plhs[0]);
   I = mxGetPr(plhs[1]);

   Iter_integral(X,w,d,m,n,Y,I);

   mxSetPr(plhs[0],Y);
   mxSetPr(plhs[1],I);
}

