% generate all words up to length d with m drivers
% L=all_words(m,d,options)
% options are pairs property/value
% 'type' decides on the output: 'list' (cell) or 'matrix'.
% 'order' decides on the order: 'first' or 'last'
% Defaults are 'list' and 'first'
% ex: L=all_words(2,4,'type','matrix','order','first')
% C.Ladroue

function L=all_words(m,d,varargin)
% default
type='list';
order='first';

% reading out options
if nargin>2,
    for k=1:2:length(varargin)
        option=varargin{k};
        value=varargin{k+1};
        switch option
            case 'type'
                type=value;
            case 'order'
                order=value;
            otherwise warning('Unknown option. Ignored.');
        end;
    end;
end;
if m>1,
    nwords=(m^(d+1)-1)/(m-1)-1;
else
    nwords=d;
end;

current=(1:m)';
switch type,
    case 'list'
        L=cell(nwords,1);
        L(1:m)=mat2cell(current,ones(1,m),1);
    case 'matrix'
        L=[zeros(m,d-1) current];
    otherwise error('Unknown type');
end;

idx=m+1;
for i=1:d-1
    H=repmat(1:m,m^i,1);
    next=repmat(current,m,1);
    switch order
        case 'last', next=[next H(:)];
        case 'first', next=[H(:) next];
        otherwise error('Unknown order');
    end;
    current=next;
    [s1 s2]=size(current);
    
    switch type
        case 'list'
            L(idx:(idx+s1-1))=mat2cell(current,ones(1,s1),size(current,2));
            idx=idx+s1;
        case 'matrix'
            L=[L;zeros(s1,d-s2) current];
        otherwise error('Unknown type');
    end;
end;

