% Computes Picard iterations where all functions are polynomials
% P=picard_poly(y0,p1,...,pn,depth)
% where y0 is the value at t=0
% p1,..,pn: polynomial of each drivers, represented by vectors
% depth: number of iterations
% P: the resulting IIxp object
% e.g.:
% P=picard_poly(1,[0 1 -3],[0.1 0.5],5); 
% for an approximate solution of dy=(y-3y^2)dt+(0.1+0.5y)dW
% C.Ladroue

function P=picard_poly(y0,varargin)

depth=varargin{end};
P=IIxp([],y0,depth);
for k=1:depth
    R=IIxp(depth); 
    for n=1:nargin-2 % driver
        poly=varargin{n};
        Q=polynomial(P,poly);
        R=R+X(Q,n);
    end;
    P=y0+R;
end;
