echo on
%% test some functions of IIsym

%% Defining an IIsym object:
P=IIsym([1],'a',[1 2],'a+b',[2 1],'c')
pause;

% Multiplication:
Q=P*P
pause;

% Addition, Soustraction:
R=Q-P
pause;

% Accessing one particular coefficient:
R([1 2])
pause;

% LaTeXify an IIsym object:
latex(R)
pause;

% Find all abstract variables in an IIsym object:
findsym(R)
pause;

% Instantiate all or some variables in an IIsym object:
S=instantiate(R,{'a' 'b' 'c'},[-1 2 0.3 ])
pause;

% All variables have been instantiated but S is still an IIsym object:
class(S)

% One can turn it into an IIxp object:
s=toIIxp(S),class(s)

%% Given the values for the drivers, one can replace the iterated integrals
%% by their values and obtain a symbolic object:
% NOTE: this is slow, and should take between 30 sec to 1 min.

dt=1E-3;resolution=1E3;
Drivers=[dt*(0:resolution-1);[0 cumsum(randn(1,resolution-1)*sqrt(dt))]];
tic; v=estimate(Q,Drivers);class(v),t_est=toc

%% Given the values for the variables, one can instantiate the symbolic
%% object
% NOTE: this is also slow, and should take between 30 sec to 1 min.

tic; v=subs(v,{'a' 'b' 'c'},[-1 0.1 0.5]);t_subs=toc

% So in total, this took t1=t_est+t_subs sec
t1=t_est+t_subs;

pause;

% But if you know the values for both the drivers and the abstract
% variables\n and use fastestimate instead:
tic;v2=fastestimate(Q,{'a' 'b' 'c'},[-1 0.1 0.5],Drivers);t_fe=toc

% Fastestimate is thus much times faster by a factor 
t1/t_fe

% The two estimations are virtually identical:
norm(v-v2)


echo off